@@ -15,7 +15,7 @@
 (**************************************************************************)
 
 module From = Ast_405
-module To = Ast_404
+module To = Ast_406
 
 let rec copy_expression :
   From.Parsetree.expression -> To.Parsetree.expression =
@@ -25,11 +25,9 @@ let rec copy_expression :
       From.Parsetree.pexp_attributes = pexp_attributes }
      ->
     {
-      To.Parsetree.pexp_desc =
-        (copy_expression_desc pexp_desc);
+      To.Parsetree.pexp_desc = (copy_expression_desc pexp_desc);
       To.Parsetree.pexp_loc = (copy_location pexp_loc);
-      To.Parsetree.pexp_attributes =
-        (copy_attributes pexp_attributes)
+      To.Parsetree.pexp_attributes = (copy_attributes pexp_attributes)
     }
 
 and copy_expression_desc :
@@ -132,7 +130,7 @@ and copy_expression_desc :
           (copy_core_type x2))
   | From.Parsetree.Pexp_send (x0,x1) ->
       To.Parsetree.Pexp_send
-        ((copy_expression x0), x1.From.Asttypes.txt)
+        ((copy_expression x0), (copy_loc (fun x  -> x) x1))
   | From.Parsetree.Pexp_new x0 ->
       To.Parsetree.Pexp_new
         (copy_loc copy_longident x0)
@@ -169,7 +167,7 @@ and copy_expression_desc :
         (copy_class_structure x0)
   | From.Parsetree.Pexp_newtype (x0,x1) ->
       To.Parsetree.Pexp_newtype
-        (x0.From.Asttypes.txt, (copy_expression x1))
+        ((copy_loc (fun x  -> x) x0), (copy_expression x1))
   | From.Parsetree.Pexp_pack x0 ->
       To.Parsetree.Pexp_pack (copy_module_expr x0)
   | From.Parsetree.Pexp_open (x0,x1,x2) ->
@@ -333,8 +331,9 @@ and copy_core_type_desc :
         ((List.map
             (fun x  ->
                let (x0,x1,x2) = x  in
-               (x0.From.Asttypes.txt, (copy_attributes x1),
-                 (copy_core_type x2))) x0),
+               To.Parsetree.Otag
+                 (copy_loc (fun x  -> x) x0, (copy_attributes x1),
+                  (copy_core_type x2))) x0),
           (copy_closed_flag x1))
   | From.Parsetree.Ptyp_class (x0,x1) ->
       To.Parsetree.Ptyp_class
@@ -350,7 +349,7 @@ and copy_core_type_desc :
           (copy_option (fun x  -> List.map copy_label x) x2))
   | From.Parsetree.Ptyp_poly (x0,x1) ->
       To.Parsetree.Ptyp_poly
-        ((List.map (fun x  -> x.From.Asttypes.txt) x0), (copy_core_type x1))
+        ((List.map (fun x  -> copy_loc (fun x  -> x) x) x0), (copy_core_type x1))
   | From.Parsetree.Ptyp_package x0 ->
       To.Parsetree.Ptyp_package (copy_package_type x0)
   | From.Parsetree.Ptyp_extension x0 ->
@@ -372,7 +371,7 @@ and copy_row_field :
   function
   | From.Parsetree.Rtag (x0,x1,x2,x3) ->
       To.Parsetree.Rtag
-        ((copy_label x0),
+        (({ txt = copy_label x0; loc = Location.none; }),
           (copy_attributes x1), (copy_bool x2),
           (List.map copy_core_type x3))
   | From.Parsetree.Rinherit x0 ->
@@ -572,7 +571,7 @@ and copy_class_field_desc :
       To.Parsetree.Pcf_inherit
         ((copy_override_flag x0),
           (copy_class_expr x1),
-          (copy_option (fun x  -> x.From.Asttypes.txt) x2))
+          (copy_option (copy_loc (fun x  -> x)) x2))
   | From.Parsetree.Pcf_val x0 ->
       To.Parsetree.Pcf_val
         (let (x0,x1,x2) = x0  in
@@ -720,11 +719,12 @@ and copy_with_constraint :
           (copy_loc copy_longident x1))
   | From.Parsetree.Pwith_typesubst x0 ->
       To.Parsetree.Pwith_typesubst
-        (copy_type_declaration x0)
+        (copy_loc (fun x -> Longident.Lident x) x0.From.Parsetree.ptype_name,
+         copy_type_declaration x0)
   | From.Parsetree.Pwith_modsubst (x0,x1) ->
       To.Parsetree.Pwith_modsubst
-        ((copy_loc (fun x  -> x) x0),
-          (copy_loc copy_longident x1))
+        (copy_loc (fun x -> Longident.Lident x) x0,
+         copy_loc copy_longident x1)
 
 and copy_signature :
   From.Parsetree.signature -> To.Parsetree.signature =
@@ -872,13 +872,13 @@ and copy_class_type_field_desc :
   | From.Parsetree.Pctf_val x0 ->
       To.Parsetree.Pctf_val
         (let (x0,x1,x2,x3) = x0  in
-         (x0.From.Asttypes.txt, (copy_mutable_flag x1),
+         (copy_loc (fun x  -> x) x0, (copy_mutable_flag x1),
            (copy_virtual_flag x2),
            (copy_core_type x3)))
   | From.Parsetree.Pctf_method x0 ->
       To.Parsetree.Pctf_method
         (let (x0,x1,x2,x3) = x0  in
-         (x0.From.Asttypes.txt, (copy_private_flag x1),
+         (copy_loc (fun x  -> x) x0, (copy_private_flag x1),
            (copy_virtual_flag x2),
            (copy_core_type x3)))
   | From.Parsetree.Pctf_constraint x0 ->
@@ -1606,11 +1606,8 @@ and copy_out_variant :
               let (x0,x1,x2) = x  in
               (x0, (copy_bool x1),
                 (List.map copy_out_type x2))) x0)
-  | From.Outcometree.Ovar_typ (From.Outcometree.Otyp_constr (id,tyl)) ->
-      To.Outcometree.Ovar_name (copy_out_ident id, List.map copy_out_type tyl)
   | From.Outcometree.Ovar_typ x0 ->
-      To.Outcometree.Ovar_name
-        (To.Outcometree.Oide_ident "", [copy_out_type x0])
+      To.Outcometree.Ovar_typ (copy_out_type x0)
 
 and copy_out_value :
   From.Outcometree.out_value -> To.Outcometree.out_value =
@@ -1643,7 +1640,8 @@ and copy_out_value :
               let (x0,x1) = x  in
               ((copy_out_ident x0),
                 (copy_out_value x1))) x0)
-  | From.Outcometree.Oval_string x0 -> To.Outcometree.Oval_string x0
+  | From.Outcometree.Oval_string x0 ->
+      To.Outcometree.Oval_string (x0, max_int, Ostr_string)
   | From.Outcometree.Oval_stuff x0 -> To.Outcometree.Oval_stuff x0
   | From.Outcometree.Oval_tuple x0 ->
       To.Outcometree.Oval_tuple
