@@ -13,22 +13,23 @@
 (*                                                                        *)
 (**************************************************************************)
 
-include Migrate_parsetree_407_408_migrate
+include Migrate_parsetree_410_409_migrate
 
 (*$ open Printf
-    let fields = [
-      "attribute"; "attributes"; "case"; "cases"; "class_declaration";
-      "class_description"; "class_expr"; "class_field"; "class_signature";
-      "class_structure"; "class_type"; "class_type_declaration";
-      "class_type_field"; "constructor_declaration"; "expr"; "extension";
-      "extension_constructor"; "include_declaration"; "include_description";
-      "label_declaration"; "location"; "module_binding"; "module_declaration";
-      "module_expr"; "module_type"; "module_type_declaration";
-      "open_description"; "pat"; "signature"; "signature_item"; "structure";
-      "structure_item"; "typ"; "type_declaration"; "type_extension";
-      "type_kind"; "value_binding"; "value_description";
-      "with_constraint"; "payload"
-    ]
+  let fields = [
+    "attribute"; "attributes"; "case"; "cases"; "class_declaration";
+    "class_description"; "class_expr"; "class_field"; "class_signature";
+    "class_structure"; "class_type"; "class_type_declaration";
+    "class_type_field"; "constructor_declaration"; "expr"; "extension";
+    "extension_constructor"; "include_declaration"; "include_description";
+    "label_declaration"; "location"; "module_binding"; "module_declaration";
+    "module_expr"; "module_type"; "module_type_declaration";
+    "open_description"; "pat"; "signature"; "signature_item"; "structure";
+    "structure_item"; "typ"; "type_declaration"; "type_extension";
+    "type_kind"; "value_binding"; "value_description";
+    "with_constraint"; "payload";
+    "binding_op"; "module_substitution"; "open_declaration"; "type_exception"
+  ]
   let foreach_field f =
     printf "\n";
     List.iter f fields
@@ -77,16 +78,18 @@ let copy_mapper = fun
      value_description;
      with_constraint;
      payload;
+     binding_op;
+     module_substitution;
+     open_declaration;
+     type_exception;
      (*$*)
    } as mapper) ->
   let module Def = Migrate_parsetree_def in
-  let migration_error location feature =
-    raise (Def.Migration_error (feature, location)) in
-  let module R = Migrate_parsetree_408_407_migrate in
+  let module R = Migrate_parsetree_409_410_migrate in
   {
     To.Ast_mapper.
     (*$ foreach_field (fun s ->
-          printf
+        printf
           "%s = (fun _ x -> copy_%s (%s mapper (R.copy_%s x)));\n" s s s s)
     *)
     attribute = (fun _ x -> copy_attribute (attribute mapper (R.copy_attribute x)));
@@ -129,10 +132,9 @@ let copy_mapper = fun
     value_description = (fun _ x -> copy_value_description (value_description mapper (R.copy_value_description x)));
     with_constraint = (fun _ x -> copy_with_constraint (with_constraint mapper (R.copy_with_constraint x)));
     payload = (fun _ x -> copy_payload (payload mapper (R.copy_payload x)));
+    binding_op = (fun _ x -> copy_binding_op (binding_op mapper (R.copy_binding_op x)));
+    module_substitution = (fun _ x -> copy_module_substitution (module_substitution mapper (R.copy_module_substitution x)));
+    open_declaration = (fun _ x -> copy_open_declaration (open_declaration mapper (R.copy_open_declaration x)));
+    type_exception = (fun _ x -> copy_type_exception (type_exception mapper (R.copy_type_exception x)));
     (*$*)
-    (* The following ones were introduced in 4.08. *)
-    binding_op = (fun _ x -> migration_error x.pbop_op.Location.loc Def.Pexp_letop);
-    module_substitution = (fun _ x -> migration_error x.pms_loc Def.Psig_modsubst);
-    open_declaration = (fun _ x -> migration_error x.popen_loc Def.Pexp_open);
-    type_exception = (fun _ x -> migration_error x.ptyexn_loc Def.Psig_typesubst);
   }
